# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['functional',
 'pycomex',
 'pycomex.app',
 'pycomex.examples',
 'pycomex.examples.results.003_analysing.28_04_2023__11_24__X6WZ',
 'pycomex.examples.results.003_analysing.28_04_2023__11_34__OGJh',
 'pycomex.examples.results.004_inheritance.28_04_2023__11_50__26gS',
 'pycomex.examples.results.004_inheritance.28_04_2023__11_52__5dHf',
 'pycomex.examples.results.basic.28_04_2023__11_16__r89L',
 'pycomex.examples.results.basic.28_04_2023__11_18__N5KA',
 'pycomex.examples.results.quickstart.debug',
 'pycomex.functional']

package_data = \
{'': ['*'], 'pycomex': ['templates/*']}

install_requires = \
['click>=7.1.2',
 'jinja2>=3.0.3',
 'matplotlib>=3.5.3',
 'numpy>=1.22.0',
 'psutil>=5.7.2']

entry_points = \
{'console_scripts': ['pycomex = pycomex.cli:main']}

setup_kwargs = {
    'name': 'pycomex',
    'version': '0.9.1',
    'description': 'Python Computational Experiments',
    'long_description': '.. image:: https://img.shields.io/pypi/v/pycomex.svg\n        :target: https://pypi.python.org/pypi/pycomex\n\n.. image:: https://readthedocs.org/projects/pycomex/badge/?version=latest\n        :target: https://pycomex.readthedocs.io/en/latest/?version=latest\n        :alt: Documentation Status\n\nPyComex - Python Computational Experiments\n================================================\n\nMicroframework to improve the experience of running and managing archival records of computational\nexperiments, such as machine learning and data science experiments, in Python.\n\n* Free software: MIT license\n\nFeatures\n--------\n\n* Automatically create (nested) folder structure for results of each run of an experiment\n* Simply attach metadata such as performance metrics to experiment object and they will be automatically\n  stored as JSON file\n* Easily attach file artifacts such as ``matplotlib`` figures to experiment records\n* Log messages to stdout as well as permanently store into log file\n* Ready-to-use automatically generated boilerplate code for the analysis and post-processing of\n  experiment data after experiments have terminated.\n* Experiment inheritance: Experiment modules can inherit from other modules and extend their functionality\n  via parameter overwrites and hooks!\n\nInstallation\n------------\n\nInstall stable version with ``pip``\n\n.. code-block:: console\n\n    pip3 install pycomex\n\nOr the most recent development version\n\n.. code-block:: console\n\n    git clone https://github.com/the16thpythonist/pycomex.git\n    cd pycomex ; pip3 install .\n\nQuickstart\n----------\n\nEach computational experiment has to be bundled as a standalone python module. Important experiment\nparameters are placed at the top of this module. All variable names written in upper case will automatically\nbe detected as parameters of the experiment.\n\nThe actual implementation of the experiment execution is placed into a single file which will have to be\ndecorated with the ``Experiment`` decorator.\n\nUpon execution the experiment, a new archive folder is automatically created. This archive folder can\nbe used to store all the file artifacts that are created during the experiment.\nSome artifacts are stored automatically by default, such as a JSON file containing all data stored in the\nmain experiment storage, a snapshot of the experiment module and more...\n\nArchiving of metadata, file artifacts and error handling is automatically managed on context exit.\n\n.. code-block:: python\n\n    # quickstart.py\n    """\n    This doc string will be saved as the "description" meta data of the experiment records\n    """\n    import os\n    from pycomex.functional.experiment import Experiment\n    from pycomex.utils import folder_path, file_namespace\n\n    # Experiment parameters can simply be defined as uppercase global variables.\n    # These are automatically detected and can possibly be overwritten in command\n    # line invocation\n    HELLO = "hello "\n    WORLD = "world!"\n\n    # There are certain special parameters which will be detected by the experiment\n    # such as this, which will put the experiment into debug mode.\n    # That means instead of creating a new archive for every execution, it will always\n    # create/overwrite the "debug" archive folder.\n    __DEBUG__ = True\n\n    # An experiment is essentially a function. All of the code that constitutes\n    # one experiment should ultimately be called from this one function...\n\n    # The main experiment function has to be decorated with the "Experiment"\n    # decorator, which needs three main arguments:\n    # - base_path: The absolute string path to an existing FOLDER, where the\n    #   archive structure should be created\n    # - namespace: This is a relative path which defines the concrete folder\n    #   structure of the specific archive folder for this specific experiment\n    # - glob: The globals() dictionary for the current file\n    @Experiment(base_path=os.getcwd(),\n                namespace=\'results/quickstart\',\n                glob=globals())\n    def experiment(e: Experiment):\n        # Internally saved into automatically created nested dict\n        # {\'strings\': {\'hello_world\': \'...\'}}\n        e["strings/hello_world"] = HELLO + WORLD\n\n        # Alternative to "print". Message is printed to stdout as well as\n        # recorded to log file\n        e.log("some debug message")\n\n        # Automatically saves text file artifact to the experiment record folder\n        file_name = "hello_world.txt"\n        e.commit_raw(file_name, HELLO + WORLD)\n        # e.commit_fig(file_name, fig)\n        # e.commit_png(file_name, image)\n        # ...\n\n\n    @experiment.analysis\n    def analysis(e: Experiment):\n        # And we can access all the internal fields of the experiment object\n        # and the experiment parameters here!\n        print(HELLO, WORLD)\n        print(e[\'strings/hello_world\'])\n        # logging will print to stdout but not modify the log file\n        e.log(\'analysis done\')\n\n\n    # This needs to be put at the end of the experiment. This method will\n    # then actually execute the main experiment code defined in the function\n    # above.\n    # NOTE: The experiment will only be run if this module is directly\n    # executed (__name__ == \'__main__\'). Otherwise the experiment will NOT\n    # be executed, which implies that the experiment module can be imported\n    # from somewhere else without triggering experiment execution!\n    experiment.run_if_main()\n\n\nThis example would create the following folder structure:\n\n.. code-block:: python\n\n    cwd\n    |- results\n       |- quickstart\n          |- debug\n             |+ experiment_out.log     # Contains all the log messages printed by experiment\n             |+ experiment_meta.json   # Meta information about the experiment\n             |+ experiment_data.json   # All the data that was added to the internal exp. dict\n             |+ hello_world.txt        # Text artifact that was committed to the experiment\n             |+ code.py                # Copy of the original experiment python module\n             |+ analysis.py            # boilerplate code to get started with analysis of results\n\nThe ``analysis.py`` file is of special importance. It is created as a boilerplate starting\nplace for additional code, which performs analysis or post processing on the results of the experiment.\nThis can for example be used to transform data into a different format or create plots for visualization.\n\nSpecifically note these two aspects:\n\n1. The analysis file contains all of the code which was defined in the ``analysis`` function of the\n   original experiment file! This code snippet is automatically transferred at the end of the experiment.\n2. The analysis file actually imports the snapshot copy of the original experiment file. This does not\n   trigger the experiment to be executed again! The ``Experiment`` instance automatically notices that it\n   is being imported and not explicitly executed. It will also populate all of it\'s internal attributes\n   from the persistently saved data in ``experiment_data.json``, which means it is still possible to access\n   all the data of the experiment without having to execute it again!\n\n.. code-block:: python\n\n    # analysis.py\n\n    # [...] imports omitted\n    from code import *\n    from pycomex.functional.experiment import Experiment\n\n    PATH = pathlib.Path(__file__).parent.absolute()\n    # "Experiment.load" is used to load the the experiment data from the\n    # archive. it returns an "Experiment" object which will act exactly the\n    # same way as if the experiment had just finished it\'s execution!\n    CODE_PATH = os.path.join(PATH, \'code.py\')\n    experiment = Experiment.load(CODE_PATH)\n    experiment.analyses = []\n\n    # All of the following code is automatically extracted from main\n    # experiment module itself and can now be edited and re-executed.\n    # Re-execution of this analysis.py file will not trigger an\n    # execution of the experiment but all the stored results will be\n    # available anyways!\n    @experiment.analysis\n    def analysis(e: Experiment):\n        # And we can access all the internal fields of the experiment\n        # object and the experiment parameters here!\n        print(HELLO, WORLD)\n        print(e[\'strings/hello_world\'])\n        # logging will print to stdout but not modify the log file\n        e.info(\'analysis done\')\n\n\n    # This method will execute only the analysis code!\n    experiment.execute_analyses()\n\n\nFor an introduction to more advanced features take a look at the examples in\n``pycomex/examples`` ( https://github.com/the16thpythonist/pycomex/tree/master/pycomex/examples )\n\nCredits\n-------\n\nThis package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.\n\n.. _Cookiecutter: https://github.com/audreyr/cookiecutter\n.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage\n',
    'author': 'Jonas Teufel',
    'author_email': 'jonseb1998@gmail.com',
    'maintainer': 'Jonas Teufel',
    'maintainer_email': 'jonseb1998@gmail.com',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8',
}


setup(**setup_kwargs)
